Module build_data

Module build_data 

Handles data required for generating a Makefile.

It extracts appropriate file names and categorizes them as source files or header files. It also generates output file names for source files (.o for C/C++ and .class for Java).

Structs

BuildData
A struct that holds data for generating a Makefile.